/*
 * Copyright (C) 1997 and 1998 WIDE Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by WIDE Project and
 *	its contributors.
 * 4. Neither the name of the project nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE PROJECT AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE PROJECT OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
/*
 * $Id: globals.c,v 1.26 1998/07/18 06:22:50 itojun Exp $
 */

#include "mgp.h"

/*
 * Global variables common to "mgp" and "mgp2ps".
 * (hate to define these in two places, mgp.c and print.c, I've made
 * a separate file)
 */
u_char *page_data[MAXPAGE][MAXLINE];
struct ctrl *page_control[MAXPAGE][MAXLINE];
struct ctrl *default_control[MAXLINE];
struct ctrl *tab_control[MAXTAB+MAXSTYLE];
struct ctrl *init_control[MAXLINE];
struct ctrl *fontdef_control[MAXFONTDEF];

u_int mgp_flag;
u_int maxpage;
u_int cur_page = 0;
char *mgp_fname;

u_int parse_error = 0;
u_int parse_debug = 0;

Display *display;
Visual *visual;
Window window;
Window text_window;
int screen;
int window_width;
int window_height;
Pixmap pixmap;
Colormap colormap;
int free_clr_num;
u_long *free_clr = NULL;

u_int char_size;
u_int horiz_gap = DEFAULT_HGAP;
u_int vert_gap = DEFAULT_VGAP;
u_int depth;
u_long fore_color;
u_long back_color;
u_long ctrl_color;
u_int b_quality = DEFAULT_BQUALITY;
u_int quality_flag = 0;

struct alloc_color image_clr = {0, NULL};
struct alloc_color back_clr = {0, NULL};
struct alloc_color font_clr = {0, NULL};

const struct ctl_words ctl_words[] = {
/*CTL*/	{ CTL_NOOP, "noop", 4 },
/*CTL*/	{ CTL_DEFAULT, "default", 7 },
/*CTL*/	{ CTL_TAB, "tab", 3 },
/*CTL*/	{ CTL_SIZE, "size", 4 },
/*CTL*/	{ CTL_FORE, "fore", 4 },
/*CTL*/	{ CTL_BACK, "back", 4 },
/*CTL*/	{ CTL_LEFT, "left", 4 },
/*CTL*/	{ CTL_LEFTFILL, "leftfill", 4 },
/*CTL*/	{ CTL_CENTER, "center", 6 },
/*CTL*/	{ CTL_RIGHT, "right", 5 },
/*CTL*/	{ CTL_SHRINK, "shrink", 6 },
/*CTL*/	{ CTL_LCUTIN, "lcutin", 6 },
/*CTL*/	{ CTL_RCUTIN, "rcutin", 6 },
/*CTL*/	{ CTL_CONT, "cont", 4 },
/*CTL*/	{ CTL_NODEF, "nodefault", 9 },
/*CTL*/	{ CTL_XFONT, "xfont", 5 },
/*CTL*/	{ CTL_VFONT, "vfont", 5 },
/*CTL*/	{ CTL_TFONT, "tfont", 5 },
/*CTL*/	{ CTL_IMAGE, "image", 5 },
/*CTL*/	{ CTL_BIMAGE, "bimage", 6 },
/*CTL*/	{ CTL_PAGE, "page", 4 },
/*CTL*/	{ CTL_HGAP, "hgap", 4 },
/*CTL*/	{ CTL_VGAP, "vgap", 4 },
/*CTL*/	{ CTL_GAP, "gap", 3 },
/*CTL*/	{ CTL_PAUSE, "pause", 5 },
/*CTL*/	{ CTL_PREFIX, "prefix", 6 },
/*CTL*/	{ CTL_TABPREFIX, "*tabprefix*", 11 },
/*CTL*/	{ CTL_PREFIXPOS, "*prefixpos*", 11 },
/*CTL*/	{ CTL_AGAIN, "again", 5 },
/*CTL*/	{ CTL_CCOLOR, "ccolor", 6 },
/*CTL*/	{ CTL_BAR, "bar", 3 },
/*CTL*/	{ CTL_INCLUDE, "include", 7 },
/*CTL*/	{ CTL_BGRAD, "bgrad", 5 },
/*CTL*/	{ CTL_TEXT, "*text*", 6 },
/*CTL*/	{ CTL_LINESTART, "*linestart*", 11 },
/*CTL*/	{ CTL_LINEEND, "*lineend*", 9 },
/*CTL*/	{ CTL_MARK, "mark", 4 },
/*CTL*/	{ CTL_SYSTEM, "system", 6 },
/*CTL*/	{ CTL_FILTER, "filter", 6 },
/*CTL*/	{ CTL_ENDFILTER, "endfilter", 9 },
/*CTL*/	{ CTL_QUALITY, "bquality", 8 },
/*CTL*/	{ CTL_ICON, "icon", 4 },
/*CTL*/	{ CTL_XSYSTEM, "xsystem", 7 },
/*CTL*/	{ CTL_TFDIR, "tfdir", 5 },
/*CTL*/	{ CTL_DEFFONT, "deffont", 7 },
/*CTL*/	{ CTL_FONT, "font", 4 },
/*CTL*/	{ CTL_VFCAP, "vfcap", 5 },
/*CTL*/	{ CTL_TFONT0, "tfont0", 6 },
	{ 0, NULL, 0 },
};
